Color

Struct Color 

pub struct Color<T, W = D65>
where T: FloatNumber,
{ /* private fields */ }
The color representation.

Type Parameters

  • T - The floating point type.
  • W - The white point type.

Examples

use std::str::FromStr;

use auto_palette::color::Color;

let color: Color<f32> = Color::from_str("#2c7de7").unwrap();
assert!(color.is_light());
assert!(color.lightness() - 52.917 < 1e-3);
assert!(color.chroma() - 61.981 < 1e-3);
assert!(color.hue().to_degrees() - 282.662 < 1e-3);

let rgb = color.to_rgb();
assert_eq!(format!("{}", rgb), "RGB(44, 125, 231)");

let hsl = color.to_hsl();
assert_eq!(format!("{}", hsl), "HSL(214.01, 0.80, 0.54)");

let lab = color.to_lab();
assert_eq!(format!("{}", lab), "Lab(52.92, 13.59, -60.47)");

Implementations

Source

impl<T, W> Color<T, W>
where T: FloatNumber, W: WhitePoint,

pub fn is_light(&self) -> bool

Returns whether this color is light.

Returns

true if the color is light, otherwise false.

pub fn is_dark(&self) -> bool

Returns whether this color is dark.

Returns

true if the color is dark, otherwise false.

pub fn lightness(&self) -> T

Returns the lightness of this color.

Returns

The lightness of this color.

pub fn chroma(&self) -> T

Returns the chroma of this color.

Returns

The chroma of this color.

pub fn delta_e(&self, other: &Self) -> T

Calculates the delta E76 value between this color and another color.

Arguments
  • other - The other color to compare against.
Returns

The delta E76 value, which is a measure of the difference between two colors.

Note

This method uses the CIE76 formula, which is a simple Euclidean distance in the Lab* color space. Color difference CIE76 - Wikipedia

pub fn hue(&self) -> Hue<T>

Returns the hue of this color. The hue is the angle of the vector in the ab plane.

Returns

The hue of this color.

pub fn to_hex_string(&self) -> String

Converts this color to a hexadecimal string.

Returns

The hexadecimal string representation of this color.

pub fn to_rgb(&self) -> RGB

Converts this color to the RGB color space.

Returns

The converted RGB color.

pub fn to_cmyk(&self) -> CMYK<T>

Converts this color to the CMYK color space.

Returns

The converted CMYK color.

pub fn to_hsl(&self) -> HSL<T>

Converts this color to the HSL color space.

Returns

The converted HSL color.

pub fn to_hsv(&self) -> HSV<T>

Converts this color to the HSV color space.

Returns

The converted HSV color.

pub fn to_xyz(&self) -> XYZ<T>

Converts this color to the CIE XYZ color space.

Returns

The converted XYZ color.

pub fn to_luv(&self) -> Luv<T, W>

Converts this color to the CIE Luv* color space.

Returns

The converted Luv color.

pub fn to_lchuv(&self) -> LCHuv<T, W>

Converts this color to the CIE LCH(uv) color space.

Returns

The converted LCHuv color.

pub fn to_lab(&self) -> Lab<T, W>

Converts this color to the CIE Lab* color space.

Returns

The converted Lab color.

pub fn to_lchab(&self) -> LCHab<T, W>

Converts this color to the CIE LCH(ab) color space.

Returns

The converted LCHab color.

pub fn to_oklab(&self) -> Oklab<T>

Converts this color to the CIE Oklab color space.

Returns

The converted Oklab color.

pub fn to_oklch(&self) -> Oklch<T>

Converts this color to the CIE Oklch color space.

Returns

The converted Oklch color.

pub fn to_ansi16(&self) -> Ansi16

Converts this color to the 4-bit ANSI 16 color space.

Returns

The converted Ansi16 color.

pub fn to_ansi256(&self) -> Ansi256

Converts this color to the 8-bit ANSI 256 color space.

Returns

The converted Ansi256 color.

pub fn to_rgb_int(&self) -> u32

Converts this color to a 32-bit integer representation in RGB.

Returns

The converted RGB integer representation.

pub fn to_rgba_int(&self, alpha: u8) -> u32

Converts this color to a 32-bit integer representation in RGBA.

Arguments
  • alpha - The alpha value (0-255).
Returns

The converted RGBA integer representation.

pub fn mix(&self, other: &Self, fraction: T) -> Self

Mixes this color with another color by a given fraction.

Arguments
  • other - The other color to mix with.
  • fraction - The fraction to mix the two colors (0.0 to 1.0).
Returns

A new Color instance that is the result of mixing the two colors.